//+------------------------------------------------------------------+
//|                                         EMA-Crossover_Signal.mq4 |
//|         Copyright  2005, Jason Robinson (jnrtrading)            |
//|                   http://www.jnrtading.co.uk                     |
//+------------------------------------------------------------------+

/*
  +------------------------------------------------------------------+
  | Allows you to enter two ema periods and it will then show you at |
  | Which point they crossed over. It is more usful on the shorter   |
  | periods that get obscured by the bars / candlesticks and when    |
  | the zoom level is out. Also allows you then to remove the emas   |
  | from the chart. (emas are initially set at 5 and 6)              |
  +------------------------------------------------------------------+
*/   
#property copyright "Copyright  2005, Jason Robinson (jnrtrading)"
#property link      "http://www.jnrtrading.co.uk"

#include <gSpeak.mqh> 

#property indicator_chart_window
#property indicator_buffers 2
#property indicator_color1 DarkGreen
#property indicator_color2 Red

extern bool alertsOn      = true;
extern int  TimeFrame     = 0;
extern int  FasterMA      = 5;
extern int  FasterMode    = 1; //0=sma, 1=ema, 2=smma, 3=lwma
extern int  FasterMAPrice = 0; //0=Close,1=Open,2=High,3=Low,4=Median,5=Typical,6=Weighted 
extern int  SlowerMA      = 50;
extern int  SlowerMode    = 1; //0=sma, 1=ema, 2=smma, 3=lwma
extern int  SlowerMAPrice = 0; //0=Close,1=Open,2=High,3=Low,4=Median,5=Typical,6=Weighted
extern int  BarsCount     = 500;

double CrossUp[];
double CrossDown[];

double alertTag;
//+------------------------------------------------------------------+
//| Custom indicator initialization function                         |
//+------------------------------------------------------------------+
  int init()
  {
//---- indicators
   SetIndexStyle (0, DRAW_ARROW, EMPTY);
   SetIndexArrow (0, 233);
   SetIndexBuffer(0, CrossUp);
   SetIndexStyle (1, DRAW_ARROW, EMPTY);
   SetIndexArrow (1, 234);
   SetIndexBuffer(1, CrossDown);
//----
   return(0);
  }
//+------------------------------------------------------------------+
//| Custom indicator deinitialization function                       |
//+------------------------------------------------------------------+
  int deinit()
  {
//---- 

//----
  return(0);
  }
//+------------------------------------------------------------------+
//| Custom indicator iteration function                              |
//+------------------------------------------------------------------+
   int start()
   {
   int limit, i, counter;
   double fasterMAnow, slowerMAnow, fasterMAprevious, slowerMAprevious, 
          fasterMAafter, slowerMAafter;
   double Range, AvgRange;
   int counted_bars=IndicatorCounted();

//---- check for possible errors
   if(counted_bars<0) return(-1);

//---- last counted bar will be recounted
   if(counted_bars>0) counted_bars--;
   limit=MathMax(Bars-counted_bars,TimeFrame/Period());
   limit= MathMin(limit,BarsCount);
   
//------   
   for(i = 0; i <= limit; i++)
      {
      counter=i;
      Range=0;
      AvgRange=0;
      for (counter=i ;counter<=i+9;counter++)
        {
         AvgRange=AvgRange+MathAbs(High[counter]-Low[counter]);
        }
      Range=AvgRange/10;
       
      fasterMAnow = iMA(NULL, TimeFrame, FasterMA, 0, FasterMode, FasterMAPrice, i);
      fasterMAprevious = iMA(NULL, TimeFrame, FasterMA, 0, FasterMode, PRICE_CLOSE, i+1);
      fasterMAafter = iMA(NULL, TimeFrame, FasterMA, 0, FasterMode, PRICE_CLOSE, i-1);

      slowerMAnow = iMA(NULL, TimeFrame, SlowerMA, 0, SlowerMode, SlowerMAPrice, i);
      slowerMAprevious = iMA(NULL, TimeFrame, SlowerMA, 0, SlowerMode, PRICE_OPEN, i+1);
      slowerMAafter = iMA(NULL, TimeFrame, SlowerMA, 0, SlowerMode, PRICE_OPEN, i-1);
      
      if ( (fasterMAnow > slowerMAnow) && (fasterMAprevious < slowerMAprevious) && (fasterMAafter > slowerMAafter)) 
         {
         CrossUp[i] = Low[i] - Range*0.8;
         if ( alertTag!=Time[0])
      if (alertsOn)
         {
          PlaySound("MovingAverageIsUp.wav");// buy wav
          Alert(Symbol(),"  M",Period(),": MA"+FasterMA+"-"+FasterMode+" - "+SlowerMA+"-"+SlowerMode+" [M"+TimeFrame+"] ", "(",TimeToStr(TimeLocal(),TIME_SECONDS),") Up ... is MA39_M15 & MACD2021_M30 Up");
         }
          alertTag = Time[0];
         }
      else if ((fasterMAnow < slowerMAnow) && (fasterMAprevious > slowerMAprevious) && (fasterMAafter < slowerMAafter))
         {
         CrossDown[i] = High[i] + Range*0.8;
         if ( alertTag!=Time[0])
         {
          PlaySound("MovingAverageIsUp.wav"); //sell wav
           Alert(Symbol(),"  M",Period(),": MA"+FasterMA+"-"+FasterMode+" - "+SlowerMA+"-"+SlowerMode+" [M"+TimeFrame+"] ", "(",TimeToStr(TimeLocal(),TIME_SECONDS),") Dn ... is MA39_M15 & MACD2021_M30 Dn");
         }
          alertTag = Time[0];
         }
         }
   return(0);
}


       